@@ -3,7 +3,7 @@
 
  Lincoln Stein <lincoln.stein@gmail.com>
  Ben Faga <ben.faga@gmail.com>
- $Id: controller.js,v 1.98 2009/06/05 18:55:11 lstein Exp $
+ $Id: controller.js,v 1.100 2009/07/03 16:44:54 lstein Exp $
 
 Indentation courtesy of Emacs javascript-mode 
 (http://mihai.bazon.net/projects/emacs-javascript-mode/javascript.el)
@@ -259,6 +259,8 @@ var GBrowseController = Class.create({
 	      && ($('autocomplete_choices') != null)) {
 	    	initAutocomplete();
 	    }
+	  if (section_name == page_title_id)
+	     document.title = $(section_name).innerHTML;
         }
       }
     });
@@ -374,7 +376,6 @@ var GBrowseController = Class.create({
     
         // Update the segment sections
         Controller.update_sections( Controller.segment_observers.keys());
-
         $('details_msg').innerHTML = results.details_msg;
         Controller.get_multiple_tracks(track_keys);
         if (results.display_details == 0){
@@ -600,7 +601,7 @@ var GBrowseController = Class.create({
   // Track Configure Methods ****************************************
 
   reconfigure_track:
-  function(track_id, form_element) {
+  function(track_id, form_element, semantic_label) {
 
     if (form_element==null)
        form_element = $("track_config_form");
@@ -613,7 +614,8 @@ var GBrowseController = Class.create({
     new Ajax.Request(document.URL,{
       method:     'post',
       parameters: form_element.serialize() +"&"+ $H({
-            reconfigure_track: track_id
+            reconfigure_track: track_id,
+	    semantic_label: semantic_label
           }).toQueryString(),
       onSuccess: function(transport) {
         var track_div_id = Controller.gbtracks.get(track_id).track_div_id;
